from charmhelpers.core.hookenv import log

import os
import pwd


class UnixUser(object):
    def __init__(self, username):
        self.username = username
        pwnam = pwd.getpwnam(username)
        self.uid = pwnam.pw_uid
        self.gid = pwnam.pw_gid

    def __enter__(self):
        log("Raising UID to {uid} and GID to {uid}".format(uid=self.uid,
                                                           gid=self.gid), 'INFO')
        os.setresgid(self.gid, self.gid, os.getgid())
        os.setresuid(self.uid, self.uid, os.getuid())

    def __exit__(self, exc_type, exc_val, exc_tb):
        _, _, suid = os.getresuid()
        _, _, sgid = os.getresgid()
        log("Restoring UID to {suid} and GID to {sgid}".format(suid=suid,
                                                               sgid=sgid), 'INFO')
        os.setresuid(suid, suid, suid)
        os.setresgid(sgid, sgid, sgid)


def pull(repository):
    '''  This will do a sort of git reset --hard origin/master '''
    origin = [remote for remote in repository.remotes if remote.name == 'origin'][0]
    origin.fetch()
    remote_master_id = repository.lookup_reference('refs/remotes/origin/master').target
    repository.checkout_tree(repository.get(remote_master_id))
    master_ref = repository.lookup_reference('refs/heads/master')
    master_ref.set_target(remote_master_id)
    repository.head.set_target(remote_master_id)
